@@ -39,7 +39,7 @@ def test_evidence():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs(llm=OpenAI(temperature=0.1, model_name="text-curie-001"))
+    docs = paperqa.Docs()
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     for evidence in docs.get_evidence(
         paperqa.Answer("For which state was he a governor"), k=1, max_sources=1
@@ -55,7 +55,7 @@ def test_query():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs(llm=OpenAI(temperature=0.1, model_name="text-ada-001"))
+    docs = paperqa.Docs()
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     answer = docs.query("What is Frederick Bates's greatest accomplishment?")
     os.remove(doc_path)
@@ -67,7 +67,7 @@ def test_query_gen():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs(llm=OpenAI(temperature=0.1, model_name="text-ada-001"))
+    docs = paperqa.Docs()
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     i = 0
     for answer in docs.query_gen("What is Frederick Bates's greatest accomplishment?"):
@@ -82,9 +82,9 @@ def test_docs_pickle():
         # get front page of wikipedia
         r = requests.get("https://en.wikipedia.org/wiki/National_Flag_of_Canada_Day")
         f.write(r.text)
-    llm = llm = OpenAI(temperature=0.0, model_name="text-babbage-001")
+    llm = OpenAI(temperature=0.0, model_name="text-babbage-001")
     docs = paperqa.Docs(llm=llm)
-    docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
+    docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now", chunk_chars=1000)
     docs_pickle = pickle.dumps(docs)
     docs2 = pickle.loads(docs_pickle)
     docs2.update_llm(llm)
@@ -112,7 +112,7 @@ def test_docs_pickle():
 
 
 def test_bad_context():
-    doc_path = "example.txt"
+    doc_path = "example.html"
     with open(doc_path, "w", encoding="utf-8") as f:
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
@@ -125,6 +125,7 @@ def test_bad_context():
         "What year was Barack Obama born?",
         length_prompt="about 20 words",
     )
+    print(answer.context)
     assert "cannot answer" in answer.answer
     os.remove(doc_path)
 
@@ -135,7 +136,7 @@ def test_repeat_keys():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-ada-003"))
+    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-ada-001"))
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     try:
         docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
@@ -174,7 +175,7 @@ def test_prompt_length():
         # get wiki page about politician
         r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
         f.write(r.text)
-    docs = paperqa.Docs(llm=OpenAI(temperature=0.0, model_name="text-ada-001"))
+    docs = paperqa.Docs()
     docs.add(doc_path, "WikiMedia Foundation, 2023, Accessed now")
     docs.query("What is the name of the politician?", length_prompt="25 words")
 
@@ -197,3 +198,14 @@ def test_code():
     docs.add(doc_path, "test_paperqa.py", key="test", disable_check=True)
     assert len(docs.docs) == 1
     answer = docs.query("What function tests the preview?")
+
+
+def test_citation():
+    doc_path = "example.txt"
+    with open(doc_path, "w", encoding="utf-8") as f:
+        # get wiki page about politician
+        r = requests.get("https://en.wikipedia.org/wiki/Frederick_Bates_(politician)")
+        f.write(r.text)
+    docs = paperqa.Docs()
+    docs.add(doc_path)
+    assert list(docs.docs.values())[0]["metadata"][0]["key"] == "Wikipedia2023"
